@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,8 +37,7 @@
 #include <cassert>
 #include <cstring>
 
-#include "Randomizer.h"
-#include "Util.h"
+#include "util.h"
 #include "array_fun.h"
 #include "bitfield.h"
 
@@ -81,7 +80,6 @@ BitfieldMan::BitfieldMan(const BitfieldMan& bitfieldMan)
    bitfield(new unsigned char[bitfieldLength]),
    useBitfield(new unsigned char[bitfieldLength]),
    filterBitfield(0),
-   randomizer(bitfieldMan.randomizer),
    cachedNumMissingBlock(0),
    cachedNumFilteredBlock(0),
    cachedCompletedLength(0),
@@ -144,51 +142,9 @@ size_t BitfieldMan::getBlockLength(size_t index) const
   }
 }
 
-size_t
-BitfieldMan::getNthBitIndex(const unsigned char bitfield, size_t nth) const
+bool BitfieldMan::hasMissingPiece
+(const unsigned char* peerBitfield, size_t length) const
 {
-  size_t index = 0;
-  for(int bs = 7; bs >= 0; --bs) {
-    unsigned char mask = 1 << bs;
-    if(bitfield & mask) {
-      nth--;
-      if(nth == 0) {
-	index = 7-bs;
-	break;
-      }
-    }
-  }
-  return index;
-}
-
-template<typename Array>
-bool BitfieldMan::getMissingIndexRandomly(size_t& index,
-					  const Array& bitfield,
-					  size_t bitfieldLength) const
-{
-  size_t byte = randomizer->getRandomNumber(bitfieldLength);
-  for(size_t i = 0; i < bitfieldLength; ++i) {
-    unsigned char mask;
-    if(byte == bitfieldLength-1) {
-      mask = bitfield::lastByteMask(blocks);
-    } else {
-      mask = 0xff;
-    }
-    unsigned char bits = bitfield[byte];
-
-    if(bits&mask) {
-      index = byte*8+getNthBitIndex(bits, 1);
-      return true;
-    }
-    ++byte;
-    if(byte == bitfieldLength) {
-      byte = 0;
-    }
-  }
-  return false;
-}
-
-bool BitfieldMan::hasMissingPiece(const unsigned char* peerBitfield, size_t length) const {
   if(bitfieldLength != length) {
     return false;
   }
@@ -206,96 +162,39 @@ bool BitfieldMan::hasMissingPiece(const unsigned char* peerBitfield, size_t leng
   return retval;
 }
 
-bool BitfieldMan::getMissingIndex(size_t& index, const unsigned char* peerBitfield, size_t length) const {
-  if(bitfieldLength != length) {
-    return false;
-  }
-  if(filterEnabled) {
-    return getMissingIndexRandomly
-      (index,
-       ~array(bitfield)&array(peerBitfield)&array(filterBitfield),
-       bitfieldLength);
-  } else {
-    return getMissingIndexRandomly
-      (index, ~array(bitfield)&array(peerBitfield), bitfieldLength);
-  }
-}
-
-bool BitfieldMan::getMissingUnusedIndex(size_t& index, const unsigned char* peerBitfield, size_t length) const {
-  if(bitfieldLength != length) {
-    return false;
-  }
-  if(filterEnabled) {
-    return getMissingIndexRandomly
-      (index,
-       ~array(bitfield)&~array(useBitfield)&array(peerBitfield)&array(filterBitfield),
-       bitfieldLength);
-  } else {
-    return getMissingIndexRandomly
-      (index,
-       ~array(bitfield)&~array(useBitfield)&array(peerBitfield),
-       bitfieldLength);
-  }
-}
-
-template<typename Array>
-bool BitfieldMan::getFirstMissingIndex(size_t& index, const Array& bitfield, size_t bitfieldLength) const
-{
-  for(size_t i = 0; i < bitfieldLength; ++i) {
-    unsigned char bits = bitfield[i];
-    unsigned char mask = 128;
-    size_t tindex = i*8;
-    for(size_t bi = 0; bi < 8 && tindex < blocks; ++bi, mask >>= 1, ++tindex) {
-      if(bits & mask) {
-	index = tindex;
-	return true;
-      }
-    }
-  }
-  return false;
-}
-
 bool BitfieldMan::getFirstMissingUnusedIndex(size_t& index) const
 {
   if(filterEnabled) {
-    return getFirstMissingIndex
+    return bitfield::getFirstMissingIndex
       (index, ~array(bitfield)&~array(useBitfield)&array(filterBitfield),
-       bitfieldLength);
+       blocks);
   } else {
-    return getFirstMissingIndex
-      (index, ~array(bitfield)&~array(useBitfield),
-       bitfieldLength);
+    return bitfield::getFirstMissingIndex
+      (index, ~array(bitfield)&~array(useBitfield), blocks);
+  }
+}
+
+size_t BitfieldMan::getFirstNMissingUnusedIndex
+(std::vector<size_t>& out, size_t n) const
+{
+  if(filterEnabled) {
+    return bitfield::getFirstNMissingIndex
+      (std::back_inserter(out), n,
+       ~array(bitfield)&~array(useBitfield)&array(filterBitfield), blocks);
+  } else {
+    return bitfield::getFirstNMissingIndex
+      (std::back_inserter(out), n,
+       ~array(bitfield)&~array(useBitfield), blocks);
   }
 }
 
 bool BitfieldMan::getFirstMissingIndex(size_t& index) const
 {
   if(filterEnabled) {
-    return getFirstMissingIndex(index, ~array(bitfield)&array(filterBitfield),
-				bitfieldLength);
+    return bitfield::getFirstMissingIndex
+      (index, ~array(bitfield)&array(filterBitfield), blocks);
   } else {
-    return getFirstMissingIndex(index, ~array(bitfield), bitfieldLength);
-  }
-}
-
-bool BitfieldMan::getMissingIndex(size_t& index) const {
-  if(filterEnabled) {
-    return getMissingIndexRandomly
-      (index, ~array(bitfield)&array(filterBitfield), bitfieldLength);
-  } else {
-    return getMissingIndexRandomly(index, ~array(bitfield), bitfieldLength);
-  }
-}
-
-bool BitfieldMan::getMissingUnusedIndex(size_t& index) const
-{
-  if(filterEnabled) {
-    return getMissingIndexRandomly
-      (index, ~array(bitfield)&~array(useBitfield)&array(filterBitfield),
-       bitfieldLength);
-  } else {
-    return getMissingIndexRandomly
-      (index, ~array(bitfield)&~array(useBitfield), bitfieldLength);
+    return bitfield::getFirstMissingIndex(index, ~array(bitfield), blocks);
   }
 }
 
@@ -332,14 +231,14 @@ static bool getSparseMissingUnusedIndex
     size_t nextIndex = 0;
     while(nextIndex < blocks) {
       currentRange.startIndex =
-	getStartIndex(nextIndex, bitfield, blocks);
+        getStartIndex(nextIndex, bitfield, blocks);
       if(currentRange.startIndex == blocks) {
-	break;
+        break;
       }
       currentRange.endIndex =
-	getEndIndex(currentRange.startIndex, bitfield, blocks);
+        getEndIndex(currentRange.startIndex, bitfield, blocks);
       if(maxRange < currentRange) {
-	maxRange = currentRange;
+        maxRange = currentRange;
       }
       nextIndex = currentRange.endIndex;
     }
@@ -401,8 +300,8 @@ bool BitfieldMan::getAllMissingIndexes(unsigned char* misbitfield, size_t len)
 }
 
 bool BitfieldMan::getAllMissingIndexes(unsigned char* misbitfield, size_t len,
-				       const unsigned char* peerBitfield,
-				       size_t peerBitfieldLength) const
+                                       const unsigned char* peerBitfield,
+                                       size_t peerBitfieldLength) const
 {
   assert(len == bitfieldLength);
   if(bitfieldLength != peerBitfieldLength) {
@@ -420,9 +319,9 @@ bool BitfieldMan::getAllMissingIndexes(unsigned char* misbitfield, size_t len,
 }
 
 bool BitfieldMan::getAllMissingUnusedIndexes(unsigned char* misbitfield,
-					     size_t len,
-					     const unsigned char* peerBitfield,
-					     size_t peerBitfieldLength) const
+                                             size_t len,
+                                             const unsigned char* peerBitfield,
+                                             size_t peerBitfieldLength) const
 {
   assert(len == bitfieldLength);
   if(bitfieldLength != peerBitfieldLength) {
@@ -469,7 +368,7 @@ size_t BitfieldMan::countFilteredBlockNow() const {
 
 bool BitfieldMan::setBitInternal(unsigned char* bitfield, size_t index, bool on) {
   if(blocks <= index) { return false; }
-  unsigned char mask = 128 >> index%8;
+  unsigned char mask = 128 >> (index%8);
   if(on) {
     bitfield[index/8] |= mask;
   } else {
@@ -502,7 +401,7 @@ bool BitfieldMan::isFilteredAllBitSet() const {
   if(filterEnabled) {
     for(size_t i = 0; i < bitfieldLength; ++i) {
       if((bitfield[i]&filterBitfield[i]) != filterBitfield[i]) {
-	return false;
+        return false;
       }
     }
     return true;
@@ -522,11 +421,7 @@ static bool testAllBitSet
       return false;
     }
   }
-  unsigned char b = ~((128 >> (blocks-1)%8)-1);
-  if(bitfield[length-1] != b) {
-    return false;
-  }
-  return true;
+  return bitfield[length-1] == bitfield::lastByteMask(blocks);
 }
 
 bool BitfieldMan::isAllBitSet() const
@@ -681,7 +576,7 @@ uint64_t BitfieldMan::getCompletedLength(bool useFilter) const {
     for(size_t i = 0; i < bitfieldLength; ++i) {
       temp[i] = bitfield[i];
       if(filterEnabled) {
-	temp[i] &= filterBitfield[i];
+        temp[i] &= filterBitfield[i];
       }
     }
   } else {
@@ -783,9 +678,4 @@ uint64_t BitfieldMan::getMissingUnusedLength(size_t startingIndex) const
   return length;
 }
 
-void BitfieldMan::setRandomizer(const SharedHandle<Randomizer>& randomizer)
-{
-  this->randomizer = randomizer;
-}
-
 } // namespace aria2
