@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,7 +35,6 @@
 #include "DHTConnectionImpl.h"
 
 #include <utility>
-#include <deque>
 #include <algorithm>
 
 #include "LogFactory.h"
@@ -48,18 +47,18 @@
 namespace aria2 {
 
 DHTConnectionImpl::DHTConnectionImpl():_socket(new SocketCore(SOCK_DGRAM)),
-				       _logger(LogFactory::getInstance()) {}
+                                       _logger(LogFactory::getInstance()) {}
 
 DHTConnectionImpl::~DHTConnectionImpl() {}
 
 bool DHTConnectionImpl::bind(uint16_t& port, IntSequence& ports)
 {
-  std::deque<int32_t> randPorts = ports.flush();
+  std::vector<int32_t> randPorts = ports.flush();
   std::random_shuffle(randPorts.begin(), randPorts.end(),
-		      *SimpleRandomizer::getInstance().get());
+                      *SimpleRandomizer::getInstance().get());
   
-  for(std::deque<int32_t>::const_iterator portItr = randPorts.begin();
-      portItr != randPorts.end(); ++portItr) {
+  for(std::vector<int32_t>::const_iterator portItr = randPorts.begin(),
+        eoi = randPorts.end(); portItr != eoi; ++portItr) {
     if(!(0 < (*portItr) && (*portItr) <= 65535)) {
       continue;
     }
@@ -79,7 +78,7 @@ bool DHTConnectionImpl::bind(uint16_t& port)
     std::pair<std::string, uint16_t> svaddr;
     _socket->getAddrInfo(svaddr);
     port = svaddr.second;
-    _logger->info("Bind socket for DHT. port=%u", port);
+    _logger->notice("DHT: listening to port %d", port);
     return true;
   } catch(RecoverableException& e) {
     _logger->error("Failed to bind for DHT. port=%u", e, port);
@@ -88,7 +87,7 @@ bool DHTConnectionImpl::bind(uint16_t& port)
 }
 
 ssize_t DHTConnectionImpl::receiveMessage(unsigned char* data, size_t len,
-					  std::string& host, uint16_t& port)
+                                          std::string& host, uint16_t& port)
 {
   std::pair<std::string, uint16_t> remoteHost;
   ssize_t length = _socket->readDataFrom(data, len, remoteHost);
@@ -102,7 +101,7 @@ ssize_t DHTConnectionImpl::receiveMessage(unsigned char* data, size_t len,
 }
 
 ssize_t DHTConnectionImpl::sendMessage(const unsigned char* data, size_t len,
-				       const std::string& host, uint16_t port)
+                                       const std::string& host, uint16_t port)
 {
   return _socket->writeData(data, len, host, port);
 }
