@@ -76,7 +76,7 @@ protected:
   virtual bool prepareForNextSegment();
 
 public:
-  DownloadCommand(int cuid,
+  DownloadCommand(cuid_t cuid,
                   const SharedHandle<Request>& req,
                   const SharedHandle<FileEntry>& fileEntry,
                   RequestGroup* requestGroup,
