@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -39,6 +39,7 @@
 #include "Metalinker.h"
 #include "MetalinkEntry.h"
 #include "MetalinkResource.h"
+#include "MetalinkMetaurl.h"
 #include "FileEntry.h"
 #include "a2functional.h"
 #include "A2STR.h"
@@ -48,11 +49,18 @@
 # include "messageDigest.h"
 #endif // ENABLE_MESSAGE_DIGEST
 #include "Signature.h"
-#include "Util.h"
+#include "util.h"
 
 namespace aria2 {
 
-const std::string MetalinkParserController::SHA1("sha1");
+#ifdef ENABLE_MESSAGE_DIGEST
+static bool isValidHash(const std::string& algo, const std::string& hash)
+{
+  return util::isHexDigit(hash) &&
+    MessageDigestContext::supports(algo) &&
+    MessageDigestContext::digestLength(algo)*2 == hash.size();
+}
+#endif // ENABLE_MESSAGE_DIGEST
 
 MetalinkParserController::MetalinkParserController():
   _metalinker(new Metalinker())
@@ -64,8 +72,10 @@ void MetalinkParserController::newEntryTransaction()
 {
   _tEntry.reset(new MetalinkEntry());
   _tResource.reset();
+  _tMetaurl.reset();
 #ifdef ENABLE_MESSAGE_DIGEST
   _tChecksum.reset();
+  _tChunkChecksumV4.reset();
   _tChunkChecksum.reset();
 #endif // ENABLE_MESSAGE_DIGEST
 }
@@ -75,14 +85,10 @@ void MetalinkParserController::setFileNameOfEntry(const std::string& filename)
   if(_tEntry.isNull()) {
     return;
   }
-  std::deque<std::string> elements;
-  Util::slice(elements, filename, '/');
-  std::string path = Util::joinPath(elements.begin(), elements.end());
-
   if(_tEntry->file.isNull()) {
-    _tEntry->file.reset(new FileEntry(path, 0, 0));
+    _tEntry->file.reset(new FileEntry(util::escapePath(filename), 0, 0));
   } else {
-    _tEntry->file->setPath(path);
+    _tEntry->file->setPath(util::escapePath(filename));
   }
 }
 
@@ -92,10 +98,10 @@ void MetalinkParserController::setFileLengthOfEntry(uint64_t length)
     return;
   }
   if(_tEntry->file.isNull()) {
-    _tEntry->file.reset(new FileEntry(A2STR::NIL, length, 0));
-  } else {
-    _tEntry->file->setLength(length);
+    return;
   }
+  _tEntry->file->setLength(length);
+  _tEntry->sizeKnown = true;
 }
 
 void MetalinkParserController::setVersionOfEntry(const std::string& version)
@@ -111,7 +117,7 @@ void MetalinkParserController::setLanguageOfEntry(const std::string& language)
   if(_tEntry.isNull()) {
     return;
   }
-  _tEntry->language = language;
+  _tEntry->languages.push_back(language);
 }
 
 void MetalinkParserController::setOSOfEntry(const std::string& os)
@@ -119,7 +125,7 @@ void MetalinkParserController::setOSOfEntry(const std::string& os)
   if(_tEntry.isNull()) {
     return;
   }
-  _tEntry->os = os;
+  _tEntry->oses.push_back(os);
 }
 
 void MetalinkParserController::setMaxConnectionsOfEntry(int maxConnections)
@@ -136,7 +142,9 @@ void MetalinkParserController::commitEntryTransaction()
     return;
   }
   commitResourceTransaction();
+  commitMetaurlTransaction();
   commitChecksumTransaction();
+  commitChunkChecksumTransactionV4();
   commitChunkChecksumTransaction();
   commitSignatureTransaction();
   _metalinker->entries.push_back(_tEntry);
@@ -146,7 +154,9 @@ void MetalinkParserController::commitEntryTransaction()
 void MetalinkParserController::cancelEntryTransaction()
 {
   cancelResourceTransaction();
+  cancelMetaurlTransaction();
   cancelChecksumTransaction();
+  cancelChunkChecksumTransactionV4();
   cancelChunkChecksumTransaction();
   cancelSignatureTransaction();
   _tEntry.reset();
@@ -166,6 +176,14 @@ void MetalinkParserController::setURLOfResource(const std::string& url)
     return;
   }
   _tResource->url = url;
+  // Metalink4Spec
+  if(_tResource->type == MetalinkResource::TYPE_UNKNOWN) {
+    // guess from URI sheme
+    std::string::size_type pos = url.find("://");
+    if(pos != std::string::npos) {
+      setTypeOfResource(url.substr(0, pos));
+    }
+  }
 }
 
 void MetalinkParserController::setTypeOfResource(const std::string& type)
@@ -181,6 +199,8 @@ void MetalinkParserController::setTypeOfResource(const std::string& type)
     _tResource->type = MetalinkResource::TYPE_HTTPS;
   } else if(type == MetalinkResource::BITTORRENT) {
     _tResource->type = MetalinkResource::TYPE_BITTORRENT;
+  } else if(type == MetalinkResource::TORRENT) { // Metalink4Spec
+    _tResource->type = MetalinkResource::TYPE_BITTORRENT;
   } else {
     _tResource->type = MetalinkResource::TYPE_NOT_SUPPORTED;
   }
@@ -194,12 +214,12 @@ void MetalinkParserController::setLocationOfResource(const std::string& location
   _tResource->location = location;
 }
 
-void MetalinkParserController::setPreferenceOfResource(int preference)
+void MetalinkParserController::setPriorityOfResource(int priority)
 {
   if(_tResource.isNull()) {
     return;
   }
-  _tResource->preference = preference;
+  _tResource->priority = priority;
 }
 
 void MetalinkParserController::setMaxConnectionsOfResource(int maxConnections)
@@ -215,7 +235,19 @@ void MetalinkParserController::commitResourceTransaction()
   if(_tResource.isNull()) {
     return;
   }
+#ifdef ENABLE_BITTORRENT
+  if(_tResource->type == MetalinkResource::TYPE_BITTORRENT) {
+    SharedHandle<MetalinkMetaurl> metaurl(new MetalinkMetaurl());
+    metaurl->url = _tResource->url;
+    metaurl->priority = _tResource->priority;
+    metaurl->mediatype = MetalinkMetaurl::MEDIATYPE_TORRENT;
+    _tEntry->metaurls.push_back(metaurl);
+  } else {
+    _tEntry->resources.push_back(_tResource);
+  }
+#else // !ENABLE_BITTORRENT
   _tEntry->resources.push_back(_tResource);
+#endif // !ENABLE_BITTORRENT
   _tResource.reset();
 }
 
@@ -254,7 +286,11 @@ void MetalinkParserController::setHashOfChecksum(const std::string& md)
   if(_tChecksum.isNull()) {
     return;
   }
-  _tChecksum->setMessageDigest(md);
+  if(isValidHash(_tChecksum->getAlgo(), md)) {
+    _tChecksum->setMessageDigest(md);
+  } else {
+    cancelChecksumTransaction();
+  }
 #endif // ENABLE_MESSAGE_DIGEST
 }
 
@@ -265,7 +301,8 @@ void MetalinkParserController::commitChecksumTransaction()
     return;
   }
   if(_tEntry->checksum.isNull() ||
-     _tEntry->checksum->getAlgo() != MetalinkParserController::SHA1) {
+     MessageDigestContext::isStronger(_tChecksum->getAlgo(),
+                                      _tEntry->checksum->getAlgo())) {
     _tEntry->checksum = _tChecksum;
   }
   _tChecksum.reset();
@@ -278,7 +315,85 @@ void MetalinkParserController::cancelChecksumTransaction()
   _tChecksum.reset();
 #endif // ENABLE_MESSAGE_DIGEST
 }
-  
+
+void MetalinkParserController::newChunkChecksumTransactionV4()
+{
+#ifdef ENABLE_MESSAGE_DIGEST
+  if(_tEntry.isNull()) {
+    return;
+  }
+  _tChunkChecksumV4.reset(new ChunkChecksum());
+  _tempChunkChecksumsV4.clear();
+#endif // ENABLE_MESSAGE_DIGEST
+}
+
+void MetalinkParserController::setTypeOfChunkChecksumV4(const std::string& type)
+{
+#ifdef ENABLE_MESSAGE_DIGEST
+  if(_tChunkChecksumV4.isNull()) {
+    return;
+  }
+  if(MessageDigestContext::supports(type)) {
+    _tChunkChecksumV4->setAlgo(type);
+  } else {
+    cancelChunkChecksumTransactionV4();
+  }
+#endif // ENABLE_MESSAGE_DIGEST
+}
+
+void MetalinkParserController::setLengthOfChunkChecksumV4(size_t length)
+{
+#ifdef ENABLE_MESSAGE_DIGEST
+  if(_tChunkChecksumV4.isNull()) {
+    return;
+  }
+  if(length > 0) {
+    _tChunkChecksumV4->setChecksumLength(length);
+  } else {
+    cancelChunkChecksumTransactionV4();
+  }
+#endif // ENABLE_MESSAGE_DIGEST
+}
+
+void MetalinkParserController::addHashOfChunkChecksumV4(const std::string& md)
+{
+#ifdef ENABLE_MESSAGE_DIGEST
+  if(_tChunkChecksumV4.isNull()) {
+    return;
+  }
+  if(isValidHash(_tChunkChecksumV4->getAlgo(), md)) {
+    _tempChunkChecksumsV4.push_back(md);
+  } else {
+    cancelChunkChecksumTransactionV4();
+  }
+#endif // ENABLE_MESSAGE_DIGEST  
+}
+
+void MetalinkParserController::commitChunkChecksumTransactionV4()
+{
+#ifdef ENABLE_MESSAGE_DIGEST
+  if(_tChunkChecksumV4.isNull()) {
+    return;
+  }
+  if(_tEntry->chunkChecksum.isNull() ||
+     MessageDigestContext::isStronger(_tChunkChecksumV4->getAlgo(),
+                                      _tEntry->chunkChecksum->getAlgo())) {
+    std::vector<std::string> checksums(_tempChunkChecksumsV4.begin(),
+				      _tempChunkChecksumsV4.end());
+    _tChunkChecksumV4->setChecksums(checksums);
+    _tEntry->chunkChecksum = _tChunkChecksumV4;
+  }
+  _tChunkChecksumV4.reset();
+#endif // ENABLE_MESSAGE_DIGEST
+}
+
+void MetalinkParserController::cancelChunkChecksumTransactionV4()
+{
+#ifdef ENABLE_MESSAGE_DIGEST
+  _tChunkChecksumV4.reset();
+#endif // ENABLE_MESSAGE_DIGEST
+}
+
 void MetalinkParserController::newChunkChecksumTransaction()
 {
 #ifdef ENABLE_MESSAGE_DIGEST
@@ -324,7 +439,11 @@ void MetalinkParserController::addHashOfChunkChecksum(size_t order, const std::s
   if(_tChunkChecksum.isNull()) {
     return;
   }
-  _tempChunkChecksums.push_back(std::pair<size_t, std::string>(order, md));
+  if(isValidHash(_tChunkChecksum->getAlgo(), md)) {
+    _tempChunkChecksums.push_back(std::make_pair(order, md));
+  } else {
+    cancelChunkChecksumTransaction();
+  }
 #endif // ENABLE_MESSAGE_DIGEST
 }
 
@@ -344,7 +463,11 @@ void MetalinkParserController::setMessageDigestOfChunkChecksum(const std::string
   if(_tChunkChecksum.isNull()) {
     return;
   }
-  _tempHashPair.second = md;
+  if(isValidHash(_tChunkChecksum->getAlgo(), md)) {
+    _tempHashPair.second = md;
+  } else {
+    cancelChunkChecksumTransaction();
+  }
 #endif // ENABLE_MESSAGE_DIGEST
 }
 
@@ -365,11 +488,14 @@ void MetalinkParserController::commitChunkChecksumTransaction()
     return;
   }
   if(_tEntry->chunkChecksum.isNull() ||
-     _tEntry->chunkChecksum->getAlgo() != MetalinkParserController::SHA1) {
-    std::sort(_tempChunkChecksums.begin(), _tempChunkChecksums.end(), Ascend1st<std::pair<size_t, std::string> >());
-    std::deque<std::string> checksums;
+     MessageDigestContext::isStronger(_tChunkChecksum->getAlgo(),
+                                      _tEntry->chunkChecksum->getAlgo())) {
+    std::sort(_tempChunkChecksums.begin(), _tempChunkChecksums.end(),
+              Ascend1st<std::pair<size_t, std::string> >());
+    std::vector<std::string> checksums;
     std::transform(_tempChunkChecksums.begin(), _tempChunkChecksums.end(),
-		   std::back_inserter(checksums), select2nd<std::pair<size_t, std::string> >());
+                   std::back_inserter(checksums),
+                   select2nd<std::pair<size_t, std::string> >());
     _tChunkChecksum->setChecksums(checksums);
     _tEntry->chunkChecksum = _tChunkChecksum;
   }
@@ -430,4 +556,63 @@ void MetalinkParserController::cancelSignatureTransaction()
   _tSignature.reset();
 }
 
+void MetalinkParserController::newMetaurlTransaction()
+{
+  if(_tEntry.isNull()) {
+    return;
+  }
+  _tMetaurl.reset(new MetalinkMetaurl());
+}
+
+void MetalinkParserController::setURLOfMetaurl(const std::string& url)
+{
+  if(_tMetaurl.isNull()) {
+    return;
+  }
+  _tMetaurl->url = url;
+}
+
+void MetalinkParserController::setMediatypeOfMetaurl
+(const std::string& mediatype)
+{
+  if(_tMetaurl.isNull()) {
+    return;
+  }
+  _tMetaurl->mediatype = mediatype;
+}
+
+void MetalinkParserController::setPriorityOfMetaurl(int priority)
+{
+  if(_tMetaurl.isNull()) {
+    return;
+  }
+  _tMetaurl->priority = priority;
+}
+
+void MetalinkParserController::setNameOfMetaurl(const std::string& name)
+{
+  if(_tMetaurl.isNull()) {
+    return;
+  }
+  _tMetaurl->name = name;
+}
+
+void MetalinkParserController::commitMetaurlTransaction()
+{
+  if(_tMetaurl.isNull()) {
+    return;
+  }
+#ifdef ENABLE_BITTORRENT
+  if(_tMetaurl->mediatype == MetalinkMetaurl::MEDIATYPE_TORRENT) {
+    _tEntry->metaurls.push_back(_tMetaurl);
+  }
+#endif // ENABLE_BITTORRENT
+  _tMetaurl.reset();
+}
+
+void MetalinkParserController::cancelMetaurlTransaction()
+{
+  _tMetaurl.reset();
+}
+
 } // namespace aria2
