@@ -40,10 +40,8 @@
 #include "util.h"
 #include "a2functional.h"
 #include "PeerSessionResource.h"
-#ifdef ENABLE_MESSAGE_DIGEST
-# include "MessageDigestHelper.h"
-#endif // ENABLE_MESSAGE_DIGEST
 #include "BtMessageDispatcher.h"
+#include "wallclock.h"
 
 namespace aria2 {
 
@@ -52,20 +50,17 @@ namespace aria2 {
 Peer::Peer(std::string ipaddr, uint16_t port, bool incoming):
   ipaddr(ipaddr),
   port(port),
+  _firstContactTime(global::wallclock),
   _badConditionStartTime(0),
   _seeder(false),
   _res(0),
-  _incoming(incoming)
+  _incoming(incoming),
+  _localPeer(false)
 {
   memset(_peerId, 0, PEER_ID_LENGTH);
   resetStatus();
-  std::string idSeed = ipaddr;
-  strappend(idSeed, ":", util::uitos(port));
-#ifdef ENABLE_MESSAGE_DIGEST
-  id = MessageDigestHelper::digestString(MessageDigestContext::SHA1, idSeed);
-#else
-  id = idSeed;
-#endif // ENABLE_MESSAGE_DIGEST
+  id = ipaddr;
+  strappend(id, A2STR::COLON_C, util::uitos(port));
 }
 
 Peer::~Peer()
@@ -73,7 +68,7 @@ Peer::~Peer()
   releaseSessionResource();
 }
 
-void Peer::usedBy(int32_t cuid)
+void Peer::usedBy(cuid_t cuid)
 {
   _cuid = cuid;
 }
@@ -222,24 +217,12 @@ unsigned int Peer::calculateUploadSpeed()
   return _res->getPeerStat().calculateUploadSpeed();
 }
 
-unsigned int Peer::calculateUploadSpeed(const struct timeval& now)
-{
-  assert(_res);
-  return _res->getPeerStat().calculateUploadSpeed(now);
-}
-
 unsigned int Peer::calculateDownloadSpeed()
 {
   assert(_res);
   return _res->getPeerStat().calculateDownloadSpeed();
 }
 
-unsigned int Peer::calculateDownloadSpeed(const struct timeval& now)
-{
-  assert(_res);
-  return _res->getPeerStat().calculateDownloadSpeed(now);
-}
-
 uint64_t Peer::getSessionUploadLength() const
 {
   assert(_res);
@@ -299,7 +282,7 @@ size_t Peer::countPeerAllowedIndexSet() const
   return _res->peerAllowedIndexSet().size();
 }
 
-const std::deque<size_t>& Peer::getPeerAllowedIndexSet() const
+const std::vector<size_t>& Peer::getPeerAllowedIndexSet() const
 {
   assert(_res);
   return _res->peerAllowedIndexSet();
@@ -335,26 +318,15 @@ void Peer::setAllBitfield() {
   _seeder = true;
 }
 
-void Peer::updateLatency(unsigned int latency)
-{
-  assert(_res);
-  _res->updateLatency(latency);
-}
-
-unsigned int Peer::getLatency() const
-{
-  assert(_res);
-  return _res->latency();
-}
-
 void Peer::startBadCondition()
 {
-  _badConditionStartTime.reset();
+  _badConditionStartTime = global::wallclock;
 }
 
 bool Peer::isGood() const
 {
-  return _badConditionStartTime.elapsed(BAD_CONDITION_INTERVAL);
+  return _badConditionStartTime.
+    difference(global::wallclock) >= BAD_CONDITION_INTERVAL;
 }
 
 uint8_t Peer::getExtensionMessageID(const std::string& name) const
@@ -399,13 +371,13 @@ bool Peer::isDHTEnabled() const
   return _res->dhtEnabled();
 }
 
-const Time& Peer::getLastDownloadUpdate() const
+const Timer& Peer::getLastDownloadUpdate() const
 {
   assert(_res);
   return _res->getLastDownloadUpdate();
 }
 
-const Time& Peer::getLastAmUnchoking() const
+const Timer& Peer::getLastAmUnchoking() const
 {
   assert(_res);
   return _res->getLastAmUnchoking();
@@ -422,7 +394,7 @@ void Peer::setIncomingPeer(bool incoming)
   _incoming = incoming;
 }
 
-void Peer::setFirstContactTime(const Time& time)
+void Peer::setFirstContactTime(const Timer& time)
 {
   _firstContactTime = time;
 }
