@@ -36,11 +36,13 @@
 #define _D_PIECE_H_
 
 #include "common.h"
-#include "SharedHandle.h"
+
 #include <stdint.h>
-#include <deque>
+#include <vector>
 #include <string>
 
+#include "SharedHandle.h"
+
 namespace aria2 {
 
 class BitfieldMan;
@@ -92,8 +94,16 @@ public:
     return index < piece.index;
   }
 
+  // TODO This function only used by unit tests
   bool getMissingUnusedBlockIndex(size_t& index) const;
-  bool getMissingBlockIndex(size_t& index) const;
+
+  // Appends at most n missing unused block index to indexes. For all
+  // i in retrieved indexes, call bitfield->setUseBit(i). This
+  // function just append index to indexes and it doesn't remove
+  // anything from it. Returns the number of indexes to retrieved.
+  size_t getMissingUnusedBlockIndex
+  (std::vector<size_t>& indexes, size_t n) const;
+
   bool getFirstMissingBlockIndexWithoutLock(size_t& index) const;
   bool getAllMissingBlockIndexes(unsigned char* misbitfield,
                                  size_t mislen) const;
@@ -153,8 +163,10 @@ public:
 
   bool isHashCalculated() const;
 
-  // Returns hash value in ASCII hexadecimal form.
-  // WARN: This function must be called only once.
+  // Returns hash value in ASCII hexadecimal form, which is calculated
+  // by updateHash().  Please note that this function returns hash
+  // value only once. Second invocation without updateHash() returns
+  // empty string.
   std::string getHashString();
 
   void destroyHashContext();
@@ -167,9 +179,6 @@ public:
   void reconfigure(size_t length);
 };
 
-typedef SharedHandle<Piece> PieceHandle;
-typedef std::deque<PieceHandle> Pieces;
-
 } // namespace aria2
 
 #endif // _D_PIECE_H_
