@@ -80,16 +80,17 @@ XmlRpcResponse XmlRpcMethod::execute
 template<typename InputIterator>
 static void gatherOption
 (InputIterator first, InputIterator last,
- const std::set<std::string>& changeableOptions,
+ const std::set<std::string>& allowedOptions,
  const SharedHandle<Option>& option,
  const SharedHandle<OptionParser>& optionParser)
 {
   for(; first != last; ++first) {
     const std::string& optionName = (*first).first;
-    if(changeableOptions.count(optionName) == 0) {
+    if(allowedOptions.count(optionName) == 0) {
       throw DL_ABORT_EX
         (StringFormat
-         ("%s cannot be changed or unknown option.", optionName.c_str()).str());
+         ("%s option cannot be used in this context.",
+          optionName.c_str()).str());
     } else {
       SharedHandle<OptionHandler> optionHandler =
         optionParser->findByName(optionName);
@@ -147,8 +148,7 @@ const std::set<std::string>& listChangeableOptions()
     PREF_MAX_DOWNLOAD_LIMIT,
     PREF_MAX_UPLOAD_LIMIT
   };
-  static std::set<std::string> options
-    (&OPTIONS[0], &OPTIONS[arrayLength(OPTIONS)]);
+  static std::set<std::string> options(vbegin(OPTIONS), vend(OPTIONS));
   return options;
 }
 
@@ -173,8 +173,7 @@ const std::set<std::string>& listChangeableGlobalOptions()
     PREF_MAX_OVERALL_DOWNLOAD_LIMIT,
     PREF_MAX_CONCURRENT_DOWNLOADS,
   };
-  static std::set<std::string> options
-    (&OPTIONS[0], &OPTIONS[arrayLength(OPTIONS)]);
+  static std::set<std::string> options(vbegin(OPTIONS), vend(OPTIONS));
   return options;
 }
 
