@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,60 +37,67 @@
 
 #include "common.h"
 
-#define MSG_SEGMENT_DOWNLOAD_COMPLETED _("CUID#%d - The download for one segment completed successfully.")
-#define MSG_NO_SEGMENT_AVAILABLE _("CUID#%d - No segment available.")
-#define MSG_CONNECTING_TO_SERVER _("CUID#%d - Connecting to %s:%d")
-#define MSG_SEGMENT_CHANGED _("CUID#%d - The segment changed. We send the request again with new Range header.")
-#define MSG_REDIRECT _("CUID#%d - Redirecting to %s")
-#define MSG_SENDING_REQUEST _("CUID#%d - Requesting:\n%s")
-#define MSG_RECEIVE_RESPONSE _("CUID#%d - Response received:\n%s")
-#define MSG_DOWNLOAD_ABORTED _("CUID#%d - Download aborted. URI=%s")
-#define MSG_RESTARTING_DOWNLOAD _("CUID#%d - Restarting the download. URI=%s")
-#define MSG_TORRENT_DOWNLOAD_ABORTED _("CUID#%d - Download aborted.")
-#define MSG_MAX_TRY _("CUID#%d - %d times attempted, but no success. Download aborted.")
-#define MSG_SEND_PEER_MESSAGE "CUID#%d - To: %s:%d %s"
-#define MSG_SEND_PEER_MESSAGE_WITH_INDEX "CUID#%d - To: %s:%d %s index=%d"
-#define MSG_SEND_PEER_MESSAGE_WITH_BITFIELD "CUID#%d - To: %s:%d %s %s"
-#define MSG_SEND_PEER_MESSAGE_WITH_INDEX_BEGIN_LENGTH "CUID#%d - To: %s:%d %s index=%d, begin=%d, length=%d"
-#define MSG_RECEIVE_PEER_MESSAGE "CUID#%d - From: %s:%d %s"
-#define MSG_GOT_NEW_PIECE _("CUID#%d - we got new piece. index=%d")
-#define MSG_GOT_WRONG_PIECE _("CUID#%d - we got wrong piece. index=%d")
-#define MSG_DOWNLOAD_NOT_COMPLETE _("CUID#%d - Download not complete: %s")
-#define MSG_DOWNLOAD_ALREADY_COMPLETED _("#%d - Download has already completed: %s")
-#define MSG_GOOD_CHECKSUM _("CUID#%d - Good checksum: %s")
-#define MSG_BAD_CHECKSUM _("CUID#%d - Bad checksum: %s")
-#define MSG_RESOLVING_HOSTNAME _("CUID#%d - Resolving hostname %s")
-#define MSG_NAME_RESOLUTION_COMPLETE _("CUID#%d - Name resolution complete: %s -> %s")
-#define MSG_NAME_RESOLUTION_FAILED _("CUID#%d - Name resolution for %s failed:%s")
-#define MSG_DNS_CACHE_HIT _("CUID#%d - DNS cache hit: %s -> %s")
-#define MSG_ABORT_REQUESTED _("CUID#%d - Abort requested.")
-#define MSG_CONNECTING_TO_PEER _("CUID#%d - Connecting to the peer %s")
-#define MSG_PIECE_RECEIVED _("CUID#%d - Piece received. index=%d, begin=%d, length=%d, offset=%llu, blockIndex=%d")
-#define MSG_PIECE_BITFIELD _("CUID#%d - Piece bitfield %s")
-#define MSG_REJECT_PIECE_CHOKED _("CUID#%d - Reject piece message in queue because the peer has been choked. index=%d, begin=%d, length=%d")
-#define MSG_REJECT_PIECE_CANCEL _("CUID#%d - Reject piece message in queue because cancel message received. index=%d, begin=%d, length=%d")
-#define MSG_FILE_VALIDATION_FAILURE _("CUID#%d - Exception caught while validating file integrity.")
-#define MSG_PEER_INTERESTED _("CUID#%d - Interested in the peer")
-#define MSG_PEER_NOT_INTERESTED _("CUID#%d - Not interested in the peer")
-#define MSG_DELETING_REQUEST_SLOT _("CUID#%d - Deleting request slot index=%d, blockIndex=%d")
-#define MSG_DELETING_REQUEST_SLOT_CHOKED _("CUID#%d - Deleting request slot index=%d, blockIndex=%d because localhost got choked.")
-#define MSG_DELETING_REQUEST_SLOT_TIMEOUT _("CUID#%d - Deleting request slot blockIndex=%d because of time out")
-#define MSG_DELETING_REQUEST_SLOT_ACQUIRED _("CUID#%d - Deleting request slot blockIndex=%d because the block has been acquired.")
-#define MSG_FAST_EXTENSION_ENABLED _("CUID#%d - Fast extension enabled.")
-#define MSG_EXTENDED_MESSAGING_ENABLED _("CUID#%d - Extended Messaging enabled.")
-#define MSG_FILE_ALLOCATION_FAILURE _("CUID#%d - Exception caught while allocating file space.")
-#define MSG_CONTENT_DISPOSITION_DETECTED _("CUID#%d - Content-Disposition detected. Use %s as filename")
-#define MSG_PEER_BANNED _("CUID#%d - Peer %s:%d banned.")
-#define MSG_LISTENING_PORT _("CUID#%d - Using port %d for accepting new connections")
-#define MSG_BIND_FAILURE _("CUID#%d - An error occurred while binding port=%d")
-#define MSG_INCOMING_PEER_CONNECTION _("CUID#%d - Incoming connection, adding new command CUID#%d")
-#define MSG_ACCEPT_FAILURE _("CUID#%d - Error in accepting connection")
-#define MSG_TRACKER_RESPONSE_PROCESSING_FAILED _("CUID#%d - Error occurred while processing tracker response.")
-#define MSG_TRACKER_REQUEST_CREATION_FAILED _("CUID#%d - Cannot create tracker request.")
-#define MSG_CREATING_TRACKER_REQUEST _("CUID#%d - Creating new tracker request command #%d")
-#define MSG_DHT_ENABLED_PEER _("CUID#%d - The peer is DHT-enabled.")
-#define MSG_CONNECT_FAILED_AND_RETRY "CUID#%d - Could not to connect to %s:%u."\
-  " Trying another address"
+#define MSG_SEGMENT_DOWNLOAD_COMPLETED                                  \
+  "CUID#%s - The download for one segment completed successfully."
+#define MSG_NO_SEGMENT_AVAILABLE "CUID#%s - No segment available."
+#define MSG_CONNECTING_TO_SERVER "CUID#%s - Connecting to %s:%d"
+#define MSG_REDIRECT "CUID#%s - Redirecting to %s"
+#define MSG_SENDING_REQUEST "CUID#%s - Requesting:\n%s"
+#define MSG_RECEIVE_RESPONSE "CUID#%s - Response received:\n%s"
+#define MSG_DOWNLOAD_ABORTED "CUID#%s - Download aborted. URI=%s"
+#define MSG_RESTARTING_DOWNLOAD "CUID#%s - Restarting the download. URI=%s"
+#define MSG_TORRENT_DOWNLOAD_ABORTED "CUID#%s - Download aborted."
+#define MSG_MAX_TRY                                                     \
+  "CUID#%s - %d times attempted, but no success. Download aborted."
+#define MSG_SEND_PEER_MESSAGE "CUID#%s - To: %s:%d %s"
+#define MSG_RECEIVE_PEER_MESSAGE "CUID#%s - From: %s:%d %s"
+#define MSG_GOT_NEW_PIECE "CUID#%s - we got new piece. index=%d"
+#define MSG_GOT_WRONG_PIECE "CUID#%s - we got wrong piece. index=%d"
+#define MSG_DOWNLOAD_NOT_COMPLETE "CUID#%s - Download not complete: %s"
+#define MSG_DOWNLOAD_ALREADY_COMPLETED _("GID#%s - Download has already completed: %s")
+#define MSG_RESOLVING_HOSTNAME "CUID#%s - Resolving hostname %s"
+#define MSG_NAME_RESOLUTION_COMPLETE                    \
+  "CUID#%s - Name resolution complete: %s -> %s"
+#define MSG_NAME_RESOLUTION_FAILED                      \
+  "CUID#%s - Name resolution for %s failed:%s"
+#define MSG_DNS_CACHE_HIT "CUID#%s - DNS cache hit: %s -> %s"
+#define MSG_CONNECTING_TO_PEER "CUID#%s - Connecting to the peer %s"
+#define MSG_PIECE_RECEIVED                                              \
+  "CUID#%s - Piece received. index=%d, begin=%d, length=%d, offset=%llu," \
+  " blockIndex=%d"
+#define MSG_PIECE_BITFIELD "CUID#%s - Piece bitfield %s"
+#define MSG_REJECT_PIECE_CHOKED                                         \
+  "CUID#%s - Reject piece message in queue because the peer has been choked." \
+  " index=%d, begin=%d, length=%d"
+#define MSG_REJECT_PIECE_CANCEL                                         \
+  "CUID#%s - Reject piece message in queue because cancel message received." \
+  " index=%d, begin=%d, length=%d"
+#define MSG_FILE_VALIDATION_FAILURE                             \
+  "CUID#%s - Exception caught while validating file integrity."
+#define MSG_PEER_INTERESTED "CUID#%s - Interested in the peer"
+#define MSG_PEER_NOT_INTERESTED "CUID#%s - Not interested in the peer"
+#define MSG_DELETING_REQUEST_SLOT "CUID#%s - Deleting request slot index=%d, blockIndex=%d"
+#define MSG_DELETING_REQUEST_SLOT_CHOKED "CUID#%s - Deleting request slot index=%d, blockIndex=%d because localhost got choked."
+#define MSG_DELETING_REQUEST_SLOT_TIMEOUT "CUID#%s - Deleting request slot blockIndex=%d because of time out"
+#define MSG_DELETING_REQUEST_SLOT_ACQUIRED "CUID#%s - Deleting request slot blockIndex=%d because the block has been acquired."
+#define MSG_FAST_EXTENSION_ENABLED "CUID#%s - Fast extension enabled."
+#define MSG_EXTENDED_MESSAGING_ENABLED "CUID#%s - Extended Messaging enabled."
+#define MSG_FILE_ALLOCATION_FAILURE                             \
+  "CUID#%s - Exception caught while allocating file space."
+#define MSG_CONTENT_DISPOSITION_DETECTED                        \
+  "CUID#%s - Content-Disposition detected. Use %s as filename"
+#define MSG_PEER_BANNED "CUID#%s - Peer %s:%d banned."
+#define MSG_LISTENING_PORT                                      \
+  "CUID#%s - Using port %d for accepting new connections"
+#define MSG_BIND_FAILURE "CUID#%s - An error occurred while binding port=%d"
+#define MSG_INCOMING_PEER_CONNECTION                            \
+  "CUID#%s - Incoming connection, adding new command CUID#%s"
+#define MSG_ACCEPT_FAILURE "CUID#%s - Error in accepting connection"
+#define MSG_TRACKER_RESPONSE_PROCESSING_FAILED                  \
+  "CUID#%s - Error occurred while processing tracker response."
+#define MSG_DHT_ENABLED_PEER "CUID#%s - The peer is DHT-enabled."
+#define MSG_CONNECT_FAILED_AND_RETRY            \
+  "CUID#%s - Could not to connect to %s:%u. Trying another address"
 
 #define MSG_UNRECOGNIZED_URI _("Unrecognized URI or unsupported protocol: %s")
 #define MSG_TRACKER_WARNING_MESSAGE _("Tracker returned warning message: %s")
@@ -115,11 +122,11 @@
 #define MSG_REMOVED_HAVE_ENTRY _("Removed %d have entries.")
 #define MSG_VALIDATING_FILE _("Validating file %s")
 #define MSG_ALLOCATION_COMPLETED _("%d seconds to allocate %s byte(s)")
-#define MSG_FILE_ALLOCATION_DISPATCH _("Dispatching FileAllocationCommand for CUID#%d.")
+#define MSG_FILE_ALLOCATION_DISPATCH                    \
+  "Dispatching FileAllocationCommand for CUID#%s."
 #define MSG_METALINK_QUEUEING _("Metalink: Queueing %s for download.")
 #define MSG_FILE_DOWNLOAD_COMPLETED _("Download complete: %s")
 #define MSG_SEEDING_END _("Seeding is over.")
-#define MSG_SEGMENT_FORWARDING _("CUID#%d cancels segment index=%d. CUID#%d handles it instead.")
 #define MSG_NO_CHUNK_CHECKSUM _("No chunk to verify.")
 #define MSG_GOOD_CHUNK_CHECKSUM _("Good chunk checksum. hash=%s")
 #define MSG_LOADING_COOKIE_FAILED _("Failed to load cookies from %s")
@@ -141,45 +148,46 @@
 #define MSG_NULL_TRACKER_RESPONSE _("Tracker returned null data.")
 #define MSG_WINSOCK_INIT_FAILD _("Windows socket library initialization failed")
 #define MSG_TIME_HAS_PASSED _("%d second(s) has passed. Stopping application.")
-#define MSG_SIGNATURE_SAVED _("Saved signature as %s. Please note that aria2"\
-			      " doesn't verify signatures.")
-#define MSG_SIGNATURE_NOT_SAVED _("Saving signature as %s failed. Maybe file"\
-				  " already exists.")
-#define MSG_OPENING_READABLE_SERVER_STAT_FILE_FAILED \
+#define MSG_SIGNATURE_SAVED _("Saved signature as %s. Please note that aria2" \
+                              " doesn't verify signatures.")
+#define MSG_SIGNATURE_NOT_SAVED _("Saving signature as %s failed. Maybe file" \
+                                  " already exists.")
+#define MSG_OPENING_READABLE_SERVER_STAT_FILE_FAILED    \
   _("Failed to open ServerStat file %s for read.")
 #define MSG_SERVER_STAT_LOADED _("ServerStat file %s loaded successfully.")
 #define MSG_READING_SERVER_STAT_FILE_FAILED _("Failed to read ServerStat from" \
-					      " %s.")
-#define MSG_OPENING_WRITABLE_SERVER_STAT_FILE_FAILED \
+                                              " %s.")
+#define MSG_OPENING_WRITABLE_SERVER_STAT_FILE_FAILED    \
   _("Failed to open ServerStat file %s for write.")
 #define MSG_SERVER_STAT_SAVED _("ServerStat file %s saved successfully.")
-#define MSG_WRITING_SERVER_STAT_FILE_FAILED _("Failed to write ServerStat to"\
-					      " %s.")
-#define MSG_ESTABLISHING_CONNECTION_FAILED \
+#define MSG_WRITING_SERVER_STAT_FILE_FAILED _("Failed to write ServerStat to" \
+                                              " %s.")
+#define MSG_ESTABLISHING_CONNECTION_FAILED              \
   _("Failed to establish connection, cause: %s")
 #define MSG_NETWORK_PROBLEM _("Network problem has occurred. cause:%s")
-#define MSG_LOADING_TRUSTED_CA_CERT_FAILED \
+#define MSG_LOADING_TRUSTED_CA_CERT_FAILED                              \
   _("Failed to load trusted CA certificates from %s. Cause: %s")
-#define MSG_CERT_VERIFICATION_FAILED \
+#define MSG_CERT_VERIFICATION_FAILED                    \
   _("Certificate verification failed. Cause: %s")
 #define MSG_NO_CERT_FOUND _("No certificate found.")
 #define MSG_HOSTNAME_NOT_MATCH _("Hostname not match.")
 #define MSG_NO_FILES_TO_DOWNLOAD _("No files to download.")
-#define MSG_WARN_NO_CA_CERT \
-  _("You may encounter the certificate verification error with HTTPS server."\
+#define MSG_WARN_NO_CA_CERT                                             \
+  _("You may encounter the certificate verification error with HTTPS server." \
     " See --ca-certificate and --check-certificate option.")
 #define MSG_SHOW_FILES _("Printing the contents of file '%s'...")
-#define MSG_NOT_TORRENT_METALINK _("This file is neither Torrent nor Metalink"\
-				   " file. Skipping.")
+#define MSG_NOT_TORRENT_METALINK _("This file is neither Torrent nor Metalink" \
+                                   " file. Skipping.")
 #define MSG_GID_NOT_PROVIDED "GID is not provided."
 #define MSG_CANNOT_PARSE_XML_RPC_REQUEST "Failed to parse xml-rpc request."
 #define MSG_GOOD_BYE_SEEDER "Client is in seed state: Good Bye Seeder;)"
 #define MSG_NOT_FILE _("Is '%s' a file?")
-#define MSG_INTERFACE_NOT_FOUND _("Failed to find given interface %s,"\
-				  " cause: %s")
+#define MSG_INTERFACE_NOT_FOUND _("Failed to find given interface %s,"  \
+                                  " cause: %s")
 #define MSG_METADATA_SAVED _("Saved metadata as %s.")
-#define MSG_METADATA_NOT_SAVED _("Saving metadata as %s failed. Maybe file"\
-				 " already exists.")
+#define MSG_METADATA_NOT_SAVED _("Saving metadata as %s failed. Maybe file" \
+                                 " already exists.")
+#define MSG_DIR_TRAVERSAL_DETECTED _("Detected directory traversal directive in %s")
 
 #define EX_TIME_OUT _("Timeout.")
 #define EX_INVALID_CHUNK_SIZE _("Invalid chunk size.")
