@@ -75,6 +75,9 @@
 #include "A2STR.h"
 #include "array_fun.h"
 #include "a2functional.h"
+#include "bitfield.h"
+#include "DownloadHandlerConstants.h"
+#include "RequestGroup.h"
 #ifdef ENABLE_MESSAGE_DIGEST
 # include "MessageDigestHelper.h"
 #endif // ENABLE_MESSAGE_DIGEST
@@ -255,16 +258,14 @@ bool inRFC3986ReservedChars(const char c)
     ':' , '/' , '?' , '#' , '[' , ']' , '@',
     '!' , '$' , '&' , '\'' , '(' , ')',
     '*' , '+' , ',' , ';' , '=' };
-  return std::find(&reserved[0], &reserved[arrayLength(reserved)], c) !=
-    &reserved[arrayLength(reserved)];
+  return std::find(vbegin(reserved), vend(reserved), c) != vend(reserved);
 }
 
 bool inRFC3986UnreservedChars(const char c)
 {
   static const char unreserved[] = { '-', '.', '_', '~' };
   return isAlpha(c) || isDigit(c) ||
-    std::find(&unreserved[0], &unreserved[arrayLength(unreserved)], c) !=
-    &unreserved[arrayLength(unreserved)];
+    std::find(vbegin(unreserved), vend(unreserved), c) != vend(unreserved);
 }
 
 bool inRFC2978MIMECharset(const char c)
@@ -275,8 +276,7 @@ bool inRFC2978MIMECharset(const char c)
     '`', '{', '}', '~'
   };
   return isAlpha(c) || isDigit(c) ||
-    std::find(&chars[0], &chars[arrayLength(chars)], c) !=
-    &chars[arrayLength(chars)];
+    std::find(vbegin(chars), vend(chars), c) != vend(chars);
 }
 
 bool inRFC2616HttpToken(const char c)
@@ -286,8 +286,7 @@ bool inRFC2616HttpToken(const char c)
     '^', '_', '`', '|', '~'
   };
   return isAlpha(c) || isDigit(c) ||
-    std::find(&chars[0], &chars[arrayLength(chars)], c) !=
-    &chars[arrayLength(chars)];
+    std::find(vbegin(chars), vend(chars), c) != vend(chars);
 }
 
 std::string percentEncode(const unsigned char* target, size_t len) {
@@ -680,11 +679,50 @@ std::string iso8859ToUtf8(const std::string& src)
   return dest;
 }
 
+template<typename OutputIterator>
+static void parseParam(OutputIterator out, const std::string& header)
+{
+  for(std::string::const_iterator i = header.begin(), eoi = header.end();
+      i != eoi;) {
+    std::string::const_iterator paramFirst = i;
+    std::string::const_iterator paramLast = paramFirst;
+    for(; paramLast != eoi && *paramLast != '=' && *paramLast != ';';
+        ++paramLast);
+    std::string param;
+    if(paramLast == eoi || *paramLast == ';') {
+      // No value, parmname only
+      param = std::string(paramFirst, paramLast);
+    } else {
+      for(; paramLast != eoi && *paramLast != '"' && *paramLast != ';';
+          ++paramLast);
+      if(paramLast != eoi && *paramLast == '"') {
+        // quoted-string
+        ++paramLast;
+        for(; paramLast != eoi && *paramLast != '"'; ++paramLast);
+        if(paramLast != eoi) {
+          ++paramLast;
+        }
+        param = std::string(paramFirst, paramLast);
+        for(; paramLast != eoi && *paramLast != ';'; ++paramLast);
+      } else {
+        param = std::string(paramFirst, paramLast);
+      }
+    }
+    trimSelf(param);
+    *out++ = param;
+    if(paramLast == eoi) {
+      break;
+    }
+    i = paramLast;
+    ++i;
+  }
+}
+
 std::string getContentDispositionFilename(const std::string& header)
 {
   std::string filename;
   std::vector<std::string> params;
-  split(header, std::back_inserter(params), A2STR::SEMICOLON_C, true);
+  parseParam(std::back_inserter(params), header);
   for(std::vector<std::string>::const_iterator i = params.begin(),
         eoi = params.end(); i != eoi; ++i) {
     const std::string& param = *i;
@@ -1148,14 +1186,16 @@ bool saveAs
     return false;
   }
   std::string tempFilename = strconcat(filename, "__temp");
-  std::ofstream out(tempFilename.c_str(), std::ios::binary);
-  if(!out) {
-    return false;
-  }
-  out << data;
-  out.flush();
-  if(!out) {
-    return false;
+  {
+    std::ofstream out(tempFilename.c_str(), std::ios::binary);
+    if(!out) {
+      return false;
+    }
+    out << data;
+    out.flush();
+    if(!out) {
+      return false;
+    }
   }
   return File(tempFilename).renameTo(filename);
 }
@@ -1244,10 +1284,8 @@ public:
     // We don't escape '/' because we use it as a path separator.
     static const char WIN_INVALID_PATH_CHARS[] =
       { '"', '*', ':', '<', '>', '?', '\\', '|' };
-    if(std::find(&WIN_INVALID_PATH_CHARS[0],
-                 &WIN_INVALID_PATH_CHARS[arrayLength(WIN_INVALID_PATH_CHARS)],
-                 c) !=
-       &WIN_INVALID_PATH_CHARS[arrayLength(WIN_INVALID_PATH_CHARS)]) {
+    if(std::find(vbegin(WIN_INVALID_PATH_CHARS), vend(WIN_INVALID_PATH_CHARS),
+                 c) != vend(WIN_INVALID_PATH_CHARS)) {
       return _repChar;
     }
 #endif // __MINGW32__
@@ -1263,6 +1301,49 @@ std::string escapePath(const std::string& s)
   return d;
 }
 
+bool getCidrPrefix(struct in_addr& in, const std::string& ip, int bits)
+{
+  struct in_addr t;
+  if(inet_aton(ip.c_str(), &t) == 0) {
+    return false;
+  }
+  int lastindex = bits/8;
+  if(lastindex < 4) {
+    char* p = reinterpret_cast<char*>(&t.s_addr);
+    const char* last = p+4;
+    p += lastindex;    
+    if(bits%8 != 0) {
+      *p &= bitfield::lastByteMask(bits);
+      ++p;
+    }
+    for(; p != last; ++p) {
+      *p &= 0;
+    }
+  }
+  in = t;
+  return true;
+}
+
+bool inSameCidrBlock(const std::string& ip1, const std::string& ip2, int bits)
+{
+  struct in_addr in1;
+  struct in_addr in2;
+  if(!getCidrPrefix(in1, ip1, bits) || !getCidrPrefix(in2, ip2, bits)) {
+    return false;
+  }
+  return in1.s_addr == in2.s_addr;
+}
+
+void removeMetalinkContentTypes(const SharedHandle<RequestGroup>& group)
+{
+  for(std::vector<std::string>::const_iterator i =
+	DownloadHandlerConstants::getMetalinkContentTypes().begin(),
+        eoi = DownloadHandlerConstants::getMetalinkContentTypes().end();
+      i != eoi; ++i) {
+    group->removeAcceptType(*i);
+  }
+}
+
 } // namespace util
 
 } // namespace aria2
