@@ -35,11 +35,12 @@ void DHTAnnouncePeerReplyMessageTest::testGetBencodedMessage()
   std::string transactionID(&tid[0], &tid[DHT_TRANSACTION_ID_LENGTH]);
 
   DHTAnnouncePeerReplyMessage msg(localNode, remoteNode, transactionID);
-
+  msg.setVersion("A200");
   std::string msgbody = msg.getBencodedMessage();
 
   BDE dict = BDE::dict();
   dict["t"] = transactionID;
+  dict["v"] = BDE("A200");
   dict["y"] = BDE("r");
   BDE rDict = BDE::dict();
   rDict["id"] = BDE(localNode->getID(), DHT_ID_LENGTH);
