@@ -53,11 +53,13 @@ void DHTPingMessageTest::testGetBencodedMessage()
   std::string transactionID(&tid[0], &tid[DHT_TRANSACTION_ID_LENGTH]);
 
   DHTPingMessage msg(localNode, remoteNode, transactionID);
+  msg.setVersion("A200");
 
   std::string msgbody = msg.getBencodedMessage();
 
   BDE dict = BDE::dict();
   dict["t"] = transactionID;
+  dict["v"] = BDE("A200");
   dict["y"] = BDE("q");
   dict["q"] = BDE("ping");
   BDE aDict = BDE::dict();
